[前][次][番号順一覧][スレッド一覧]

ruby-changes:28487

From: eregon <ko1@a...>
Date: Wed, 1 May 2013 19:04:41 +0900 (JST)
Subject: [ruby-changes:28487] eregon:r40539 (trunk): * enum.c (Enumerable#chunk): fix grammar of error message

eregon	2013-05-01 19:04:21 +0900 (Wed, 01 May 2013)

  New Revision: 40539

  http://svn.ruby-lang.org/cgi-bin/viewvc.cgi?view=rev&revision=40539

  Log:
    * enum.c (Enumerable#chunk): fix grammar of error message
      for symbols beginning with an underscore [Bug #8351]

  Modified files:
    trunk/ChangeLog
    trunk/enum.c

Index: ChangeLog
===================================================================
--- ChangeLog	(revision 40538)
+++ ChangeLog	(revision 40539)
@@ -1,3 +1,8 @@ https://github.com/ruby/ruby/blob/trunk/ChangeLog#L1
+Wed May  1 18:59:36 2013  Benoit Daloze  <eregontp@g...>
+
+	* enum.c (Enumerable#chunk): fix grammar of error message
+	  for symbols beginning with an underscore [Bug #8351]
+
 Wed May  1 16:47:47 2013  Nobuyoshi Nakada  <nobu@r...>
 
 	* ext/curses/extconf.rb (curses_version): try once for each tests, a
Index: enum.c
===================================================================
--- enum.c	(revision 40538)
+++ enum.c	(revision 40539)
@@ -2358,7 +2358,7 @@ chunk_ii(VALUE i, VALUE _argp, int argc, https://github.com/ruby/ruby/blob/trunk/enum.c#L2358
         }
     }
     else if (SYMBOL_P(v) && rb_id2name(SYM2ID(v))[0] == '_') {
-	rb_raise(rb_eRuntimeError, "symbol begins with an underscore is reserved");
+	rb_raise(rb_eRuntimeError, "symbols beginning with an underscore are reserved");
     }
     else {
         if (NIL_P(argp->prev_value)) {
@@ -2447,7 +2447,7 @@ chunk_i(VALUE yielder, VALUE enumerator, https://github.com/ruby/ruby/blob/trunk/enum.c#L2447
  *  Any other symbols that begin with an underscore will raise an error:
  *
  *    items.chunk { |item| :_underscore }
  *    #=> RuntimeError: symbol begins with an underscore is reserved
  *
  *  +nil+ and +:_separator+ can be used to ignore some elements.
  *
@@ -2447,7 +2447,7 @@ chunk_i(VALUE yielder, VALUE enumerator, https://github.com/ruby/ruby/blob/trunk/enum.c#L2447
  *
  *    items.chunk { |item| :_underscore }
- *    #=> RuntimeError: symbol begins with an underscore is reserved
+ *    #=> RuntimeError: symbols beginning with an underscore are reserved
  *
  *  +nil+ and +:_separator+ can be used to ignore some elements.

--
ML: ruby-changes@q...
Info: http://www.atdot.net/~ko1/quickml/

[前][次][番号順一覧][スレッド一覧]